==> auto_blob_saver-0.1.tar.gz: auto_blob_saver-0.1/README.md <==
# auto-blob-saver

[![standard-readme compliant](https://img.shields.io/badge/standard--readme-OK-green.svg?style=flat-square)](https://github.com/RichardLitt/standard-readme)

Save your blobs automatically.

## Table of Contents

- [Install](#install)
- [Usage](#usage)
- [Maintainers](#maintainers)
- [Contributing](#contributing)
- [License](#license)

## Install

NOTE: You need to install tsschecker first.

```
1. Get the latest release
2. Move it to /bin or PATH dir
3. Run 'auto_blob_saver' command
4. Once it's off, edit ~/.auto_blob_saver/devices.json for your phone
5. Run 'auto_blob_saver' command again and enjoy!

NOTE: if you're getting trouble because of 'curlcode=28' or '[Error] [TSSC] parsing firmware.json failed', run 'tsschecker --nocache -o' and try again.
```

## Usage

```
usage: auto_blob_saver [-h] [--devices DEVICES_JSON_PATH] [--shsh SHSH_DIRECTORY_PATH] [--time MILLISECONDS]

optional arguments:
  -h, --help            show this help message and exit
  --devices DEVICES_JSON_PATH
                        Sets the devices.json path
  --shsh SHSH_DIRECTORY_PATH
                        Sets the shsh directory path
  --time MILLISECONDS, -t MILLISECONDS
                        Sets shsh download time interval
```

## Maintainers

[@Helloyunho](https://github.com/Helloyunho)

## Contributing

PRs accepted.

Small note: If editing the README, please conform to the [standard-readme](https://github.com/RichardLitt/standard-readme) specification.

## License

MIT © 2020 Helloyunho

==> auto_blob_saver-0.1.1.tar.gz: auto_blob_saver-0.1.1/README.md <==
# auto-blob-saver

[![standard-readme compliant](https://img.shields.io/badge/standard--readme-OK-green.svg?style=flat-square)](https://github.com/RichardLitt/standard-readme)

Save your blobs automatically.

## Table of Contents

- [Install](#install)
- [Usage](#usage)
- [Maintainers](#maintainers)
- [Contributing](#contributing)
- [License](#license)

## Install

NOTE: You need to install tsschecker first.

```
1. Get the latest release by running pip install auto-blob-saver
3. Run 'auto_blob_saver' command
4. Once it's off, edit ~/.auto_blob_saver/devices.json for your phone
5. Run 'auto_blob_saver' command again and enjoy!

NOTE: if you're getting trouble because of 'curlcode=28' or '[Error] [TSSC] parsing firmware.json failed', run 'tsschecker --nocache -o' and try again.
```

## Usage

```
usage: auto_blob_saver [-h] [--devices DEVICES_JSON_PATH] [--shsh SHSH_DIRECTORY_PATH] [--time MILLISECONDS]

optional arguments:
  -h, --help            show this help message and exit
  --devices DEVICES_JSON_PATH
                        Sets the devices.json path
  --shsh SHSH_DIRECTORY_PATH
                        Sets the shsh directory path
  --time MILLISECONDS, -t MILLISECONDS
                        Sets shsh download time interval
```

## Maintainers

[@Helloyunho](https://github.com/Helloyunho)

## Contributing

PRs accepted.

Small note: If editing the README, please conform to the [standard-readme](https://github.com/RichardLitt/standard-readme) specification.

## License

MIT © 2020 Helloyunho
